@@ -13,6 +13,7 @@ class PFBReader(PFBBase):
         rv = super(PFBReader, self).__enter__()
         self._reader = reader(self._file_obj)
         schema = []
+        self.set_encoded_schema(self._reader.writer_schema)
         for f in self._reader.writer_schema["fields"]:
             if f["name"] == "object":
                 it = iter(f["type"])
@@ -36,7 +37,13 @@ class PFBReader(PFBBase):
         to_update = {}
         for name, value in list(obj.items()):
             if value and self.is_encode(rv["name"], name):
-                to_update[name] = decode_enum(value)
+                if isinstance(value,list):
+                    thing = []
+                    for val in value:
+                        thing.append(decode_enum(val))
+                    to_update[name] = thing
+                else:
+                    to_update[name] = decode_enum(value)
         obj.update(to_update)
         return rv
 
